@@ -3,8 +3,8 @@
 ;; Copyright (C) 2024-2025 James Cherti | https://www.jamescherti.com/contact/
 
 ;; Author: James Cherti
-;; Package-Version: 20250921.2109
-;; Package-Revision: c99cf257ab5c
+;; Package-Version: 20251103.1434
+;; Package-Revision: 832595bc0f66
 ;; URL: https://github.com/jamescherti/outline-indent.el
 ;; Keywords: outlines
 ;; Package-Requires: ((emacs "26.1"))
@@ -49,8 +49,9 @@
 ;; ------------------------
 ;; (use-package outline-indent
 ;;   :ensure t
+;;   :commands outline-indent-minor-mode
 ;;   :custom
-;;   (outline-indent-ellipsis " ▼ "))
+;;   (outline-indent-ellipsis " ▼"))
 ;;
 ;; Activation:
 ;; -----------
@@ -126,11 +127,10 @@ suitable for representing folded content."
   :type '(choice string (const nil))
   :group 'outline-indent)
 
-
 (define-obsolete-variable-alias
   'outline-indent-make-window-start-visible
   'make-window-start-visible
-  "1.1.2"
+  "1.1.4"
   "Obsolete. Use `make-window-start-visible' instead.")
 
 (defcustom outline-indent-insert-heading-add-blank-line nil
@@ -231,6 +231,12 @@ It is recommended to keep this set to t for improved behavior."
     map)
   "Keymap for `outline-indent-minor-mode'.")
 
+(defvar outline-indent-conflicting-modes
+  '(hs-minor-mode origami-mode yafolding-mode)
+  "List of minor modes that may conflict with `outline-indent-minor-mode'.
+These modes will be automatically disabled when `outline-indent-minor-mode' is
+enabled.")
+
 ;;; Internal variables
 
 (defconst outline-indent--has-ts-modes
@@ -239,66 +245,69 @@ It is recommended to keep this set to t for improved behavior."
   "Non-nil if Emacs supports tree-sitter modes (Emacs 29.1+).")
 
 (defvar outline-indent--mode-basic-offset-map
-  '((typescript-ts-base-mode typescript-ts-mode-indent-offset)
-    (ada-ts-mode     ada-ts-mode-indent-offset)
-    (sh-mode         sh-basic-offset)
-    (c++-mode        c-basic-offset)
-    (c-mode          c-basic-offset)
-    (cmake-mode      cmake-tab-width)
-    (cperl-mode      cperl-indent-level)
-    (crystal-mode    crystal-indent-level)
-    (css-mode        css-indent-offset)
-    (d-mode          c-basic-offset)
-    (default         standard-indent)
-    (enh-ruby-mode   enh-ruby-indent-level)
-    (erlang-mode     erlang-indent-level)
-    (java-mode       c-basic-offset)
-    (jde-mode        c-basic-offset)
-    (js-mode         js-indent-level)
-    (js2-mode        js2-basic-offset)
-    (js3-mode        js3-indent-level)
-    (json-mode       js-indent-level)
-    (lua-mode        lua-indent-level)
-    (nxml-mode       nxml-child-indent)
-    (objc-mode       c-basic-offset)
-    (pascal-mode     pascal-indent-level)
-    (perl-mode       perl-indent-level)
-    (php-mode        c-basic-offset)
-    (plantuml-mode   plantuml-indent-level)
-    (protobuf-mode   c-basic-offset)
-    (pug-mode        pug-tab-width)
-    (raku-mode       raku-indent-offset)
-    (ruby-mode       ruby-indent-level)
-    (rust-mode       rust-indent-offset)
-    (rustic-mode     rustic-indent-offset)
-    (scala-mode      scala-indent:step)
-    (sgml-mode       sgml-basic-offset)
-    (swift-mode      swift-mode:basic-offset)
-    (typescript-mode typescript-indent-level)
-    (ada-mode        ada-indent)
-    (bash-ts-mode    sh-basic-offset)
-    (js-json-mode    js-indent-level)
-    (c++-ts-mode     c-ts-mode-indent-offset)
-    (c-ts-mode       c-ts-mode-indent-offset)
-    (cmake-ts-mode   cmake-ts-mode-indent-offset)
-    (go-ts-mode      go-ts-mode-indent-offset)
-    (gpr-ts-mode     gpr-ts-mode-indent-offset)
-    (java-ts-mode    java-ts-mode-indent-offset)
-    (js-ts-mode      js-indent-level)
-    (json-ts-mode    json-ts-mode-indent-offset)
-    (rust-ts-mode    rust-ts-mode-indent-offset)
-    (yaml-ts-mode    yaml-indent-offset 2)
-    (python-mode     python-indent-offset)
-    (python-ts-mode  python-indent-offset)
-    (ursa-ts-mode    ursa-ts-mode-indent-offset)
-    (vhdl-mode       vhdl-basic-offset)
-    (xquery-mode     xquery-mode-indent-width)
-    (groovy-mode     groovy-indent-offset tab-width)
-    (yaml-mode       yaml-indent-offset tab-width)
-    (web-mode        web-mode-markup-indent-offset
+  (list
+   (cons 'typescript-ts-base-mode 'typescript-ts-mode-indent-offset)
+   (cons 'ada-ts-mode 'ada-ts-mode-indent-offset)
+   (cons 'sh-mode 'sh-basic-offset)
+   (cons 'c++-mode 'c-basic-offset)
+   (cons 'c-mode 'c-basic-offset)
+   (cons 'cmake-mode 'cmake-tab-width)
+   (cons 'cperl-mode 'cperl-indent-level)
+   (cons 'crystal-mode 'crystal-indent-level)
+   (cons 'css-mode 'css-indent-offset)
+   (cons 'd-mode 'c-basic-offset)
+   (cons 'default 'standard-indent)
+   (cons 'enh-ruby-mode 'enh-ruby-indent-level)
+   (cons 'erlang-mode 'erlang-indent-level)
+   (cons 'java-mode 'c-basic-offset)
+   (cons 'jde-mode 'c-basic-offset)
+   (cons 'js-mode 'js-indent-level)
+   (cons 'js2-mode 'js2-basic-offset)
+   (cons 'js3-mode 'js3-indent-level)
+   (cons 'json-mode 'js-indent-level)
+   (cons 'lua-mode 'lua-indent-level)
+   (cons 'nxml-mode 'nxml-child-indent)
+   (cons 'objc-mode 'c-basic-offset)
+   (cons 'pascal-mode 'pascal-indent-level)
+   (cons 'perl-mode 'perl-indent-level)
+   (cons 'php-mode 'c-basic-offset)
+   (cons 'plantuml-mode 'plantuml-indent-level)
+   (cons 'protobuf-mode 'c-basic-offset)
+   (cons 'pug-mode 'pug-tab-width)
+   (cons 'raku-mode 'raku-indent-offset)
+   (cons 'ruby-mode 'ruby-indent-level)
+   (cons 'rust-mode 'rust-indent-offset)
+   (cons 'rustic-mode 'rustic-indent-offset)
+   (cons 'scala-mode 'scala-indent:step)
+   (cons 'sgml-mode 'sgml-basic-offset)
+   (cons 'swift-mode 'swift-mode:basic-offset)
+   (cons 'typescript-mode 'typescript-indent-level)
+   (cons 'ada-mode 'ada-indent)
+   (cons 'bash-ts-mode 'sh-basic-offset)
+   (cons 'js-json-mode 'js-indent-level)
+   (cons 'c++-ts-mode 'c-ts-mode-indent-offset)
+   (cons 'c-ts-mode 'c-ts-mode-indent-offset)
+   (cons 'cmake-ts-mode 'cmake-ts-mode-indent-offset)
+   (cons 'go-ts-mode 'go-ts-mode-indent-offset)
+   (cons 'gpr-ts-mode 'gpr-ts-mode-indent-offset)
+   (cons 'java-ts-mode 'java-ts-mode-indent-offset)
+   (cons 'js-ts-mode 'js-indent-level)
+   (cons 'json-ts-mode 'json-ts-mode-indent-offset)
+   (cons 'rust-ts-mode 'rust-ts-mode-indent-offset)
+   (cons 'yaml-ts-mode '(yaml-indent-offset 2))
+   (cons 'python-mode 'python-indent-offset)
+   (cons 'python-ts-mode 'python-indent-offset)
+   (cons 'ursa-ts-mode 'ursa-ts-mode-indent-offset)
+   (cons 'vhdl-mode 'vhdl-basic-offset)
+   (cons 'xquery-mode 'xquery-mode-indent-width)
+   (cons 'groovy-mode '(groovy-indent-offset
+                        tab-width))
+   (cons 'yaml-mode '(yaml-indent-offset
+                      tab-width))
+   (cons 'web-mode '(web-mode-markup-indent-offset
                      web-mode-code-indent-offset
                      web-mode-sql-indent-offset
-                     web-mode-css-indent-offset))
+                     web-mode-css-indent-offset)))
   "A mapping from hook variables to language types.")
 
 ;;; Internal Functions
@@ -308,8 +317,8 @@ It is recommended to keep this set to t for improved behavior."
 Searches `outline-indent--mode-basic-offset-map', falling back to `default'."
   (when mode
     (or (assoc mode outline-indent--mode-basic-offset-map)
-        (outline-indent--get-mode-basic-offset-entry
-         (get mode 'derived-mode-parent))
+        (when-let* ((parent-mode (get mode 'derived-mode-parent)))
+          (outline-indent--get-mode-basic-offset-entry parent-mode))
         (assoc 'default outline-indent--mode-basic-offset-map))))
 
 (defun outline-indent--get-mode-basic-offset (mode)
@@ -321,6 +330,9 @@ is found."
     (let ((list-vars (cdr entry))
           result)
       (catch 'done
+        (when (symbolp list-vars)
+          (setq list-vars (list list-vars)))
+
         (dolist (var list-vars)
           (cond
            ((numberp var)
@@ -427,7 +439,11 @@ to insert content at the same indentation level after the current fold."
       (when outline-indent-insert-heading-add-blank-line
         (newline)
         (forward-line -1))
-      (indent-to initial-indentation))))
+      (indent-to initial-indentation)))
+
+  (when (and (bound-and-true-p evil-mode)
+             (fboundp 'evil-insert-state))
+    (funcall 'evil-insert-state)))
 
 (defun outline-indent-move-subtree-up (&optional arg)
   "Move the current subtree up past ARG headlines of the same level.
@@ -445,61 +461,6 @@ addressing the issue where the cursor might be reset after the operation."
     (goto-char (region-beginning))
     (deactivate-mark)))
 
-(defun outline-indent-shift-right (&optional _which arg)
-  "Increasing the indentation level.
-The global variable `outline-indent-shift-width' or
-`outline-indent-default-offset' is used to determine the number of spaces to
-indent the subtree.
-WHICH is ignored (backward compatibility with `outline-demote').
-If ARG is positive, indent the outline. If ARG is negative, unindent the
-outline. Defaults to 1 if ARG is nil."
-  (interactive)
-  (unless arg
-    (setq arg 1))
-  (outline-indent--deactivate-region)
-  (let ((shift-right (>= arg 0))
-        (column (current-column))
-        (shift-width
-         (cond (outline-indent-shift-width
-                (max outline-indent-shift-width 1))
-
-               (t
-                (max outline-indent-default-offset 1)))))
-    (let ((folded (save-match-data
-                    (outline-end-of-heading)
-                    (outline-invisible-p))))
-      (save-excursion
-        (outline-back-to-heading)
-        (let ((start (point))
-              (end (save-excursion
-                     (outline-end-of-subtree)
-                     (point))))
-          (indent-rigidly start end (if shift-right
-                                        shift-width
-                                      (* -1 shift-width)))))
-      (if shift-right
-          (move-to-column (+ column shift-width))
-        (move-to-column (max (- column shift-width) 0)))
-      (if folded
-          (outline-hide-subtree)))))
-
-(defun outline-indent-shift-left (&optional _which)
-  "Decreasing the indentation level. Equivalent to `outline-promote'.
-The global variable `outline-indent-shift-width' or
-`outline-indent-default-offset' is used to determine the number of spaces to
-unindent the subtree.
-WHICH is ignored (backward compatibility with `outline-promote')."
-  (interactive)
-  (outline-indent-shift-right nil -1))
-
-(defalias 'outline-indent-demote #'outline-indent-shift-right
-  "Deprecated alias for `outline-indent-shift-right'.")
-(make-obsolete 'outline-indent-demote 'outline-indent-shift-right "1.1.1")
-
-(defalias 'outline-indent-promote #'outline-indent-shift-left
-  "Deprecated alias for `outline-indent-shift-left'.")
-(make-obsolete 'outline-indent-promote 'outline-indent-shift-left "1.1.1")
-
 (defun outline-indent--advice-promote (orig-fun &rest args)
   "Advice function for `outline-indent-shift-left'.
 If `outline-indent-minor-mode' is active, use `outline-indent-insert-heading'.
@@ -694,54 +655,22 @@ ORIG-FUN is the original function being advised, and ARGS are its arguments."
 
 ;;; Functions
 
-(defun outline-indent-backward-same-level (&optional arg)
-  "Move backward to the ARG'th subheading at same indentation level as this one.
-Stop at the first and last indented blocks of a superior indentation."
-  (interactive "p")
-  (unless arg
-    (setq arg 1))
-  (if (advice-member-p 'outline-indent--advice-backward-same-level
-                       'outline-backward-same-level)
-      (outline-backward-same-level arg)
-    (outline-indent--advice-backward-same-level 'outline-backward-same-level
-                                                arg)))
+(defun outline-indent-folded-p ()
+  "Return non-nil when the current heading is folded."
+  (save-excursion
+    (outline-back-to-heading)
+    (outline-end-of-heading)
+    (outline-invisible-p (point))))
 
-(defun outline-indent-forward-same-level (&optional arg)
-  "Move forward to the ARG'th subheading at same indentation level as this one.
-Stop at the first and last indented blocks of a superior indentation."
-  (interactive "p")
-  (unless arg
-    (setq arg 1))
-  (if (advice-member-p 'outline-indent--advice-forward-same-level
-                       'outline-forward-same-level)
-      (outline-forward-same-level arg)
-    (outline-indent--advice-forward-same-level 'outline-forward-same-level
-                                               arg)))
+(defun outline-indent--legacy-outline-hide-subtree (&optional event)
+  "Hide everything after this heading at deeper levels.
+If non-nil, EVENT should be a mouse event."
+  (interactive (list last-nonmenu-event))
+  (save-excursion
+    (when (mouse-event-p event)
+      (mouse-set-point event))
+    (outline-flag-subtree t)))
 
-(defun outline-indent-select ()
-  "Select the indented block at point."
-  (interactive)
-  (outline-indent--deactivate-region)
-  (let ((begin (save-excursion
-                 (outline-back-to-heading)
-                 (point)))
-        (end (outline-indent--next-lower-or-equal-indentation)))
-    (goto-char (+ end 1))
-    (push-mark)
-    (goto-char begin)
-    (activate-mark)))
-
-(defun outline-indent-close-folds ()
-  "Close all folds."
-  (interactive)
-  (with-no-warnings (outline-hide-sublevels 1)))
-
-(defun outline-indent-open-folds ()
-  "Open all folds."
-  (interactive)
-  (outline-show-all))
-
-;; TODO: Use the original one
 (defun outline-indent--legacy-outline-show-entry ()
   "Show the body directly following this heading. (Emacs version.)
 Show the heading too, if it is currently invisible."
@@ -756,6 +685,69 @@ Show the heading too, if it is currently invisible."
                              (point)))
                          nil)))
 
+(defun outline-indent-close-level (level)
+  "Close the folds at the level: LEVEL."
+  (outline-hide-sublevels level))
+
+;;; Interactive functions
+
+;;;###autoload
+(defun outline-indent-backward-same-level (&optional arg)
+  "Move the cursor to the previous heading that is at the same indentation level.
+Move backward to the ARG'th subheading at same indentation level as this one.
+Stop at the first and last indented blocks of a superior indentation."
+  (interactive "p")
+  (unless arg
+    (setq arg 1))
+  (if (advice-member-p 'outline-indent--advice-backward-same-level
+                       'outline-backward-same-level)
+      (outline-backward-same-level arg)
+    (outline-indent--advice-backward-same-level 'outline-backward-same-level
+                                                arg)))
+
+;;;###autoload
+(defun outline-indent-forward-same-level (&optional arg)
+  "Move the cursor to the next heading that is at the same indentation level.
+Move forward to the ARG'th subheading at same indentation level as this one.
+Stop at the first and last indented blocks of a superior indentation."
+  (interactive "p")
+  (unless arg
+    (setq arg 1))
+  (if (advice-member-p 'outline-indent--advice-forward-same-level
+                       'outline-forward-same-level)
+      (outline-forward-same-level arg)
+    (outline-indent--advice-forward-same-level 'outline-forward-same-level
+                                               arg)))
+
+;;;###autoload
+(defun outline-indent-select ()
+  "Select the indented block at point.
+Selects the entire indented block at point, activating a visual region that
+spans the heading and all of its associated indented content."
+  (interactive)
+  (outline-indent--deactivate-region)
+  (let ((begin (save-excursion
+                 (outline-back-to-heading)
+                 (point)))
+        (end (outline-indent--next-lower-or-equal-indentation)))
+    (goto-char (+ end 1))
+    (push-mark)
+    (goto-char begin)
+    (activate-mark)))
+
+;;;###autoload
+(defun outline-indent-close-folds ()
+  "Close all folds."
+  (interactive)
+  (with-no-warnings (outline-hide-sublevels 1)))
+
+;;;###autoload
+(defun outline-indent-open-folds ()
+  "Open all folds."
+  (interactive)
+  (outline-show-all))
+
+;;;###autoload
 (defun outline-indent-open-fold ()
   "Open fold at point."
   (interactive)
@@ -777,16 +769,7 @@ Show the heading too, if it is currently invisible."
     (outline-before-first-heading
      nil)))
 
-;; TODO: Use the original one
-(defun outline-indent--legacy-outline-hide-subtree (&optional event)
-  "Hide everything after this heading at deeper levels.
-If non-nil, EVENT should be a mouse event."
-  (interactive (list last-nonmenu-event))
-  (save-excursion
-    (when (mouse-event-p event)
-      (mouse-set-point event))
-    (outline-flag-subtree t)))
-
+;;;###autoload
 (defun outline-indent-close-fold ()
   "Close fold at point."
   (interactive)
@@ -808,6 +791,7 @@ If non-nil, EVENT should be a mouse event."
     (outline-before-first-heading
      nil)))
 
+;;;###autoload
 (defun outline-indent-open-fold-rec ()
   "Open fold at point recursively."
   (interactive)
@@ -817,22 +801,13 @@ If non-nil, EVENT should be a mouse event."
     (outline-before-first-heading
      nil)))
 
+;;;###autoload
 (defun outline-indent-toggle-fold ()
   "Open or close a fold under point."
   (interactive)
   (outline-toggle-children))
 
-(defun outline-indent-folded-p ()
-  "Return non-nil when the current heading is folded."
-  (save-excursion
-    (outline-back-to-heading)
-    (outline-end-of-heading)
-    (outline-invisible-p (point))))
-
-(defun outline-indent-close-level (level)
-  "Close the folds at the level: LEVEL."
-  (outline-hide-sublevels level))
-
+;;;###autoload
 (defun outline-indent-toggle-level-at-point ()
   "Toggle the visibility of the indentation level under the cursor."
   (interactive)
@@ -848,18 +823,83 @@ If non-nil, EVENT should be a mouse event."
           (outline-hide-sublevels level)
         (outline-hide-sublevels (- level 1))))))
 
+;;;###autoload
+(defun outline-indent-shift-right (&optional _which arg)
+  "Increase the indentation level of the current indented block.
+The global variable `outline-indent-shift-width' or
+`outline-indent-default-offset' is used to determine the number of spaces to
+indent the subtree.
+WHICH is ignored (backward compatibility with `outline-demote').
+If ARG is positive, indent the outline. If ARG is negative, unindent the
+outline. Defaults to 1 if ARG is nil."
+  (interactive)
+  (unless arg
+    (setq arg 1))
+  (outline-indent--deactivate-region)
+  (let ((shift-right (>= arg 0))
+        (column (current-column))
+        (shift-width
+         (cond (outline-indent-shift-width
+                (max outline-indent-shift-width 1))
+
+               (t
+                (max outline-indent-default-offset 1)))))
+    (let ((folded (save-match-data
+                    (outline-end-of-heading)
+                    (outline-invisible-p))))
+      (save-excursion
+        (outline-back-to-heading)
+        (let ((start (point))
+              (end (save-excursion
+                     (outline-end-of-subtree)
+                     (point))))
+          (indent-rigidly start end (if shift-right
+                                        shift-width
+                                      (* -1 shift-width)))))
+      (if shift-right
+          (move-to-column (+ column shift-width))
+        (move-to-column (max (- column shift-width) 0)))
+      (if folded
+          (outline-hide-subtree)))))
+
+;;;###autoload
+(defun outline-indent-shift-left (&optional _which)
+  "Decrease the indentation level of the current indented block.
+The global variable `outline-indent-shift-width' or
+`outline-indent-default-offset' is used to determine the number of spaces to
+unindent the subtree.
+WHICH is ignored (backward compatibility with `outline-promote')."
+  (interactive)
+  (outline-indent-shift-right nil -1))
+
+(defalias 'outline-indent-demote #'outline-indent-shift-right
+  "Deprecated alias for `outline-indent-shift-right'.")
+(make-obsolete 'outline-indent-demote 'outline-indent-shift-right "1.1.1")
+
+(defalias 'outline-indent-promote #'outline-indent-shift-left
+  "Deprecated alias for `outline-indent-shift-left'.")
+(make-obsolete 'outline-indent-promote 'outline-indent-shift-left "1.1.1")
+
 ;;; Mode
 
 ;;;###autoload
 (define-minor-mode outline-indent-minor-mode
-  "Toggle `outline-indent-minor-mode'.
-This mode sets up outline to work based on indentation."
+  "Minor mode for folding text according to indentation levels."
   :lighter " OutlInd"
   :keymap outline-indent-minor-mode-map
   :group 'outline-indent
   (if outline-indent-minor-mode
       (progn
+        ;; Disable conflicting modes
+        (dolist (mode outline-indent-conflicting-modes)
+          (when (and (boundp mode)
+                     (symbol-value mode)
+                     (fboundp mode))
+            (save-excursion
+              (funcall mode -1))))
+
         (outline-indent--advise-func outline-indent-advise-outline-functions)
+
         ;; Enable minor mode
         (when (boundp 'outline-minor-mode-highlight)
           (setq-local outline-minor-mode-highlight nil))
